@@ -10,11 +10,16 @@ from testwizard.commands_mobile import InitDriverCommand
 from testwizard.commands_mobile import QuitDriverCommand
 from testwizard.commands_mobile import AddCapabilityCommand
 from testwizard.commands_mobile import Android_SendKeyCodeCommand
+from testwizard.commands_mobile import ClearElementCommand
 from testwizard.commands_mobile import ClickElementCommand
 from testwizard.commands_mobile import ClickPositionCommand
+from testwizard.commands_mobile import CloseAppCommand
+from testwizard.commands_mobile import RemoveAppCommand
 from testwizard.commands_mobile import FindElementCommand
+from testwizard.commands_mobile import GetElementCommand
 from testwizard.commands_mobile import GetElementAttributeCommand
 from testwizard.commands_mobile import GetElementLocationCommand
+from testwizard.commands_mobile import GetElementsCommand
 from testwizard.commands_mobile import GetElementSizeCommand
 from testwizard.commands_mobile import GetOrientationCommand
 from testwizard.commands_mobile import GetScreenSizeCommand
@@ -66,12 +71,12 @@ from testwizard.commands_video import FindAllPatternLocationsCommand
 from testwizard.commands_video import FindAllPatternLocationsExCommand
 from testwizard.commands_video import FindPatternCommand
 from testwizard.commands_video import FindPatternExCommand
-from testwizard.commands_video import GetVideoFormatCommand
 from testwizard.commands_video import GetVideoResolutionCommand
 from testwizard.commands_video import LoadReferenceBitmapCommand
 from testwizard.commands_video import SaveReferenceBitmapCommand
 from testwizard.commands_video import SaveRegionCommand
 from testwizard.commands_video import SetRegionCommand
+from testwizard.commands_video import SnapShotCommand
 from testwizard.commands_video import SnapShotBMPCommand
 from testwizard.commands_video import SnapShotJPGCommand
 from testwizard.commands_video import StartBackgroundCaptureCommand
@@ -98,6 +103,10 @@ class Mobile(TestObjectBase):
     def quitDriver(self):
         self.throwIfDisposed()
         return QuitDriverCommand(self).execute()
+
+    def closeApp(self):
+        self.throwIfDisposed()
+        return CloseAppCommand(self).execute()    
     
     def addCapability(self, name, value):
         self.throwIfDisposed()
@@ -107,6 +116,10 @@ class Mobile(TestObjectBase):
         self.throwIfDisposed()
         return Android_SendKeyCodeCommand(self).execute(keyCode)
     
+    def clearElement(self, selector):
+        self.throwIfDisposed()
+        return ClearElementCommand(self).execute(selector)
+
     def clickElement(self, selector):
         self.throwIfDisposed()
         return ClickElementCommand(self).execute(selector) 
@@ -119,6 +132,10 @@ class Mobile(TestObjectBase):
         self.throwIfDisposed()
         return FindElementCommand(self).execute(selector)
     
+    def getElement(self, selector):
+        self.throwIfDisposed()
+        return GetElementCommand(self).execute(selector)
+    
     def getElementAttribute(self, selector, attribute):
         self.throwIfDisposed()
         return GetElementAttributeCommand(self).execute(selector, attribute)    
@@ -127,6 +144,10 @@ class Mobile(TestObjectBase):
         self.throwIfDisposed()
         return GetElementLocationCommand(self).execute(selector)
     
+    def getElements(self, selector):
+        self.throwIfDisposed()
+        return GetElementsCommand(self).execute(selector)   
+    
     def getElementSize(self, selector):
         self.throwIfDisposed()
         return GetElementSizeCommand(self).execute(selector)   
@@ -177,7 +198,11 @@ class Mobile(TestObjectBase):
     
     def resetApp(self):
         self.throwIfDisposed()
-        return ResetAppCommand(self).execute()    
+        return ResetAppCommand(self).execute()
+
+    def removeApp(self, appId):
+        self.throwIfDisposed()
+        return RemoveAppCommand(self).execute(appId)          
     
     def runAppInBackground(self, seconds = None):
         self.throwIfDisposed()
@@ -264,10 +289,6 @@ class Mobile(TestObjectBase):
         self.throwIfDisposed()
         return CaptureReferenceBitmapCommand(self).execute()
     
-    def getVideoFormat(self):
-        self.throwIfDisposed()
-        return GetVideoFormatCommand(self).execute()
-    
     def getVideoResolution(self):
         self.throwIfDisposed()
         return GetVideoResolutionCommand(self).execute()
@@ -355,8 +376,12 @@ class Mobile(TestObjectBase):
     def snapShotBMP(self, filename):
         self.throwIfDisposed()
         return SnapShotBMPCommand(self).execute(filename)
-    
-    def snapShotJPG(self, filename, quality):
+
+    def snapShot(self, filename, imageFormat, quality  = None):
+        self.throwIfDisposed()
+        return SnapShotCommand(self).execute(filename, imageFormat, quality)
+
+    def snapShotJPG(self, filename, quality = None):
         self.throwIfDisposed()
         return SnapShotJPGCommand(self).execute(filename, quality)
     
